@@ -32,7 +32,7 @@ impl Directory {
 /// `ScopedFileSystem`
 #[derive(Debug)]
 pub enum Entry {
-    File(File),
+    File(Box<File>),
     Directory(Directory),
 }
 
@@ -101,20 +101,19 @@ impl ScopedFileSystem {
 
     async fn open(path: PathBuf) -> std::io::Result<Entry> {
         let mut open_options = OpenOptions::new();
-        open_options.read(true);
-
         let entry_path: PathBuf = path.clone();
-        let file = open_options.open(path).await?;
+        let file = open_options.read(true).open(path).await?;
         let metadata = file.metadata().await?;
 
         if metadata.is_dir() {
             return Ok(Entry::Directory(Directory { path: entry_path }));
         }
 
-        Ok(Entry::File(File::new(entry_path, file, metadata)))
+        Ok(Entry::File(Box::new(File::new(entry_path, file, metadata))))
     }
 }
 
+#[cfg(test)]
 mod tests {
     #[allow(unused_imports)]
     use super::*;
